diff --git a/data/klog.json b/data/klog.json
index 168effda..f9c72565 100644
--- a/data/klog.json
+++ b/data/klog.json
@@ -432,7 +432,7 @@
    "compare_mode": "string",
    "log_level": "LOG_LEVEL_MEDIUM",
    "pattern": "Error pre-mapping GARs",
-   "advice": "The ACPI Error Injection (EINJ) driver failed to map the address spaces specified by the injection instuction entry Generic Address Structures (GAR), EINJ functionality is disabled.",
+   "advice": "The ACPI Error Injection (EINJ) driver failed to map the address spaces specified by the injection instruction entry Generic Address Structures (GAR), EINJ functionality is disabled.",
    "label": "KlogAcpiEinjGarMapFailed",
   },
   {
@@ -4689,7 +4689,7 @@ atform Communications Channel Table (PCCT) and find the PCC subspace communicati
    "compare_mode": "string",
    "log_level": "LOG_LEVEL_HIGH",
    "pattern": "acpi_memory_enable_device() error",
-   "advice": "ACPI memory hotplug failed to add an ACPI memory device to the systen. This error can occur if the memory block has already been used by the kernel or if the ACPI memory bind failed.",
+   "advice": "ACPI memory hotplug failed to add an ACPI memory device to the system. This error can occur if the memory block has already been used by the kernel or if the ACPI memory bind failed.",
    "label": "KlogAcpiMemEnableDevice"
   },
   {
diff --git a/doc/fwts.1 b/doc/fwts.1
index 4b1e64ae..ecb34463 100644
--- a/doc/fwts.1
+++ b/doc/fwts.1
@@ -163,7 +163,7 @@ run only interactive experimental tests.
 .TP
 .B \-j, \-\-json\-data\-path
 specifies the path to the fwts json data files. These files contain json formatted
-configuation tables, for example klog scanning patterns.
+configuration tables, for example klog scanning patterns.
 .TP
 .B \-k, \-\-klog=file
 read the kernel log from the specified file rather than from the kernel log ring buffer. This
diff --git a/fwts-test/pcct-0001/pcct-0002.log b/fwts-test/pcct-0001/pcct-0002.log
index c2dd70f3..fbadd744 100644
--- a/fwts-test/pcct-0001/pcct-0002.log
+++ b/fwts-test/pcct-0001/pcct-0002.log
@@ -152,9 +152,9 @@ pcct
 pcct              PCC Subspace Structure:
 pcct                Type:                        0x04
 pcct                Length:                      0xa4
-pcct            FAILED [HIGH] PCCTBadFlags: Test 1, PCCT Plaform Interrupt
-pcct            in flags must be set when subspace type 4 is present, got
-pcct            0x00000000 instead
+pcct            FAILED [HIGH] PCCTBadFlags: Test 1, PCCT Platform
+pcct            Interrupt in flags must be set when subspace type 4 is
+pcct            present, got 0x00000000 instead
 pcct                Platform Interrupt:          0x00000001
 pcct                Platform Interrupt Flags:    0x01
 pcct                Reserved:                    0x00
diff --git a/fwts-test/wpbt-0001/wpbt-0002.log b/fwts-test/wpbt-0001/wpbt-0002.log
index 24a2b0c7..6acb79ba 100644
--- a/fwts-test/wpbt-0001/wpbt-0002.log
+++ b/fwts-test/wpbt-0001/wpbt-0002.log
@@ -6,7 +6,7 @@ wpbt              Handoff Memory Size:      0x12345678
 wpbt              Handoff Memory Location:  0xaa000000bb000000
 wpbt              Content Layout:           0x33
 wpbt              Content Type:             0x88
-wpbt            FAILED [HIGH] WPBTBadLayout: Test 1, WPBT supports Conent
+wpbt            FAILED [HIGH] WPBTBadLayout: Test 1, WPBT supports Content
 wpbt            Layout 1 only, got 0x33 instead
 wpbt            FAILED [HIGH] WPBTBadType: Test 1, WPBT supports Content
 wpbt            Type 1 only, got 0x88 instead
diff --git a/src/acpi/crsdump/crsdump.c b/src/acpi/crsdump/crsdump.c
index bd11abdc..667424e4 100644
--- a/src/acpi/crsdump/crsdump.c
+++ b/src/acpi/crsdump/crsdump.c
@@ -796,7 +796,7 @@ static void crsdump_large_resource_items(
 					"Input or Output",
 					"Input Only",
 					"Output Only",
-					"Input or Ouput, config must be preserved"
+					"Input or Output, config must be preserved"
 				};
 
 				/* I/O connection */
diff --git a/src/acpi/pcct/pcct.c b/src/acpi/pcct/pcct.c
index 8188ddb2..57cff5bf 100644
--- a/src/acpi/pcct/pcct.c
+++ b/src/acpi/pcct/pcct.c
@@ -281,7 +281,7 @@ static int pcct_test1(fwts_framework *fw)
 				passed = false;
 				fwts_failed(fw, LOG_LEVEL_HIGH,
 					"PCCTBadFlags",
-					"PCCT Plaform Interrupt in flags must be set when subspace "
+					"PCCT Platform Interrupt in flags must be set when subspace "
 					"type 4 is present, got 0x%8.8" PRIx32 " instead", pcct->flags);
 			}
 
diff --git a/src/acpi/s3/s3.c b/src/acpi/s3/s3.c
index 3870a8cd..fa7ed52b 100644
--- a/src/acpi/s3/s3.c
+++ b/src/acpi/s3/s3.c
@@ -304,7 +304,7 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 
 		if (differences > 0) {
 			fwts_failed(fw, LOG_LEVEL_HIGH, "DevConfigDiffAfterS3",
-				"Found %d differences in device configuation during S3 cycle.", differences);
+				"Found %d differences in device configuration during S3 cycle.", differences);
 			(*hw_errors)++;
 		}
 	}
diff --git a/src/acpi/wpbt/wpbt.c b/src/acpi/wpbt/wpbt.c
index 15ecfdd4..31d2d9f3 100644
--- a/src/acpi/wpbt/wpbt.c
+++ b/src/acpi/wpbt/wpbt.c
@@ -60,7 +60,7 @@ static int wpbt_test1(fwts_framework *fw)
 		passed = false;
 		fwts_failed(fw, LOG_LEVEL_HIGH,
 			"WPBTBadLayout",
-			"WPBT supports Conent Layout 1 only, got "
+			"WPBT supports Content Layout 1 only, got "
 			"0x%2.2" PRIx8 " instead", wpbt->layout);
 	}
 
diff --git a/src/acpica/source/components/tables/tbfadt.c b/src/acpica/source/components/tables/tbfadt.c
index 9691b2cd..aad5a626 100644
--- a/src/acpica/source/components/tables/tbfadt.c
+++ b/src/acpica/source/components/tables/tbfadt.c
@@ -740,7 +740,7 @@ AcpiTbConvertFadt (
                  * 64-bit X length field.
                  * Note: If the legacy length field is > 0xFF bits, ignore
                  * this check. (GPE registers can be larger than the
-                 * 64-bit GAS structure can accomodate, 0xFF bits).
+                 * 64-bit GAS structure can accommodate, 0xFF bits).
                  */
                 if ((ACPI_MUL_8 (Length) <= ACPI_UINT8_MAX) &&
                     (Address64->BitWidth != ACPI_MUL_8 (Length)))
diff --git a/src/bios/multiproc/mpdump.c b/src/bios/multiproc/mpdump.c
index 79313fa0..0ed27105 100644
--- a/src/bios/multiproc/mpdump.c
+++ b/src/bios/multiproc/mpdump.c
@@ -159,7 +159,7 @@ static void mpdump_dump_local_interrupt_entry(fwts_framework *fw, void *data, ui
 {
 	fwts_mp_local_interrupt_entry *local_interrupt_entry = (fwts_mp_local_interrupt_entry *)data;
 
-	fwts_log_info_verbatim(fw, "Local Interrupt Assignement Entry: (@0x%8.8x)", phys_addr);
+	fwts_log_info_verbatim(fw, "Local Interrupt Assignment Entry: (@0x%8.8x)", phys_addr);
 	fwts_log_info_verbatim(fw, "  Interrupt Type:     0x%2.2x (%s)", local_interrupt_entry->type,
 		local_interrupt_entry->type < 4 ? mpdump_inttype[local_interrupt_entry->type] : "Unknown");
 	fwts_log_info_verbatim(fw, "  Flags:              0x%4.4x", local_interrupt_entry->flags);
diff --git a/src/lib/src/fwts_acpi_object_eval.c b/src/lib/src/fwts_acpi_object_eval.c
index c80a9e93..a749fb01 100644
--- a/src/lib/src/fwts_acpi_object_eval.c
+++ b/src/lib/src/fwts_acpi_object_eval.c
@@ -144,7 +144,7 @@ static const acpi_eval_error errors[] = {
 		"ACPI tables or control methods."
 	},
 
-	{ AE_BAD_PARAMETER,		LOG_LEVEL_HIGH,		"AEBadParam",		"Args: Bad paramater",
+	{ AE_BAD_PARAMETER,		LOG_LEVEL_HIGH,		"AEBadParam",		"Args: Bad parameter",
 		"A parameter passed is out of range or invalid."
 	},
 	{ AE_BAD_CHARACTER,		LOG_LEVEL_HIGH,		"AEBadChar",		"Args: Bad character",
diff --git a/src/lib/src/fwts_devicetree.c b/src/lib/src/fwts_devicetree.c
index c81672ea..937bd751 100644
--- a/src/lib/src/fwts_devicetree.c
+++ b/src/lib/src/fwts_devicetree.c
@@ -256,7 +256,7 @@ int fwts_dt_property_read_u64_arr(
 	return FWTS_OK;
 }
 
-/* Get's the length of DT property string list */
+/* Gets the length of DT property string list */
 
 int fwts_dt_stringlist_count(
 	fwts_framework *fw,
diff --git a/src/uefi/securebootcert/securebootcert.c b/src/uefi/securebootcert/securebootcert.c
index 3d6771f1..99057cf3 100644
--- a/src/uefi/securebootcert/securebootcert.c
+++ b/src/uefi/securebootcert/securebootcert.c
@@ -571,7 +571,7 @@ static int securebootcert_test2(fwts_framework *fw)
 
 	if (!(var_found & VAR_AUDITMODE_FOUND)) {
 		fwts_skipped(fw,
-			"No AuditMode variable found, skip the varaible test.");
+			"No AuditMode variable found, skip the variable test.");
 		return FWTS_SKIP;
 	}
 
@@ -588,7 +588,7 @@ static int securebootcert_test2(fwts_framework *fw)
 
 	if (!(var_found & VAR_AUDITMODE_FOUND)) {
 		fwts_skipped(fw,
-			"No DeployedMode variable found, skip the varaible test.");
+			"No DeployedMode variable found, skip the variable test.");
 		return FWTS_SKIP;
 	}
 
diff --git a/src/uefi/uefirttime/uefirttime.c b/src/uefi/uefirttime/uefirttime.c
index 10e54f33..7626f06e 100644
--- a/src/uefi/uefirttime/uefirttime.c
+++ b/src/uefi/uefirttime/uefirttime.c
@@ -594,7 +594,7 @@ static int uefirttime_test16(fwts_framework *fw)
 /*
  *  The UEFI spec states that just two bits are allowed, and all other bits
  *  must be zero, but I have yet to find a compliant implementation that
- *  flags up an invalid paramater if the bits are non zero. It seems that
+ *  flags up an invalid parameter if the bits are non zero. It seems that
  *  implementations just examine the bits they expect and don't care. For
  *  now, we will ignore this test
  */
@@ -1071,7 +1071,7 @@ static int uefirttime_test36(fwts_framework *fw)
 /*
  *  The UEFI spec states that just two bits are allowed, and all other bits
  *  must be zero, but I have yet to find a compliant implementation that
- *  flags up an invalid paramater if the bits are non zero. It seems that
+ *  flags up an invalid parameter if the bits are non zero. It seems that
  *  implementations just examine the bits they expect and don't care. For
  *  now, we will ignore this test
  */

diff --git a/src/lib/src/fwts_acpi_tables.c b/src/lib/src/fwts_acpi_tables.c
index 4b227860..dcf8efd1 100644
--- a/src/lib/src/fwts_acpi_tables.c
+++ b/src/lib/src/fwts_acpi_tables.c
@@ -788,12 +788,12 @@ err_no_data:
 
 /*
  *  fwts_acpi_load_tables_from_file_generic()
  *	load acpi tables from a given path with a given file extention
  */
 static int fwts_acpi_load_tables_from_file_generic(
 	fwts_framework *fw,
 	char *acpi_table_path,
-	const char *extention,
+	const char *extension,
 	int *count)
 {
 	struct dirent **dir_entries;
@@ -816,7 +816,7 @@ static int fwts_acpi_load_tables_from_file_generic(
 		if (dir_entries[i]->d_name[0] == '.')
 			continue;
 
-		if (strstr(dir_entries[i]->d_name, extention)) {
+		if (strstr(dir_entries[i]->d_name, extension)) {
 			char path[PATH_MAX];
 			int fd;
 
@@ -788,12 +788,12 @@ err_no_data:
 /*
  *  fwts_acpi_load_tables_from_file_generic()
- *	load acpi tables from a given path with a given file extention
+ *	load acpi tables from a given path with a given file extension
  */
 static int fwts_acpi_load_tables_from_file_generic(